<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       info@meteosales.com
 * @since      1.0.0
 *
 * @package    Meteosales
 * @subpackage Meteosales/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Meteosales
 * @subpackage Meteosales/admin
 * @author     MeteoSales <info@meteosales.com>
 */
class Meteosales_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Meteosales_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Meteosales_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/meteosales-admin.css', array(), $this->version, 'all' );
		wp_register_style( 'meteosales-bootstrap-min-css', plugin_dir_url( __FILE__ ) . '/css/bootstrap.min.css', array(), $this->version, 'all' );
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Meteosales_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Meteosales_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/meteosales-admin.js', array( 'jquery' ), $this->version, false );
	}
	
	function meteosales_my_plugin_menu(){
        
		add_menu_page( "MeteoSales", "MeteoSales", "manage_options", "meteo_sales", "meteoSales_homepage_callback", plugins_url('images/meteosales_20.png', __FILE__) , 8);
		add_submenu_page("meteo_sales", "Settings", "Settings", "manage_options", "general_setting","meteoSales_settings_callback");
			add_submenu_page("meteo_sales", "Banner Settings", "Banner Settings", "manage_options", "banner_setting","meteoSales_banner_settings_callback");
		//// check for woocommerce exists or not
		function meteoSales_homepage_callback(){
			if (!current_user_can('manage_options'))  {
				wp_die( __('You do not have sufficient permissions to access this page.') );
			}
			require_once plugin_dir_path( __FILE__ ) . 'partials/meteosales_homepage.php';
		}
		
		function meteoSales_settings_callback(){
			if (!current_user_can('manage_options'))  {
				wp_die( __('You do not have sufficient permissions to access this page.') );
			}
			require_once plugin_dir_path( __FILE__ ) . 'partials/meteosales_settings.php';
		}
		
		function meteoSales_banner_settings_callback(){
			if (!current_user_can('manage_options'))  {
				wp_die( __('You do not have sufficient permissions to access this page.') );
			}
			require_once plugin_dir_path( __FILE__ ) . 'partials/meteosales_banner_settings.php';
		}
	}
	
}
