<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              info@meteosales.com
 * @since             1.0.0
 * @package           Meteosales
 *
 * @wordpress-plugin
 * Plugin Name:       MeteoSales
 * Plugin URI:        https://meteosales.com/
 * Description:       The Swiss army knife solutions for WooCommerce
 * Version:           1.0.16
 * Author:            MeteoSales
 * Author URI:        info@meteosales.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       meteosales
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'METEOSALES_VERSION', '1.0.16' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-meteosales-activator.php
 */
function activate_meteosales() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-meteosales-activator.php';
	Meteosales_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-meteosales-deactivator.php
 */
function deactivate_meteosales() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-meteosales-deactivator.php';
	Meteosales_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_meteosales' );
register_deactivation_hook( __FILE__, 'deactivate_meteosales' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-meteosales.php';
require plugin_dir_path( __FILE__ ) . 'includes/display_homepage.php';
require plugin_dir_path( __FILE__ ) . 'includes/sync_products.php';
require plugin_dir_path( __FILE__ ) . 'includes/products_order.php';
require plugin_dir_path( __FILE__ ) . 'includes/update_product_description.php';
require plugin_dir_path( __FILE__ ) . 'includes/product_clicks_ajax.php';
/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_meteosales() {

	$plugin = new Meteosales();
	$plugin->run();

}
run_meteosales();
